Package: seminr
Type: Package
Title: Building and Estimating Structural Equation Models
Version: 2.5.0
Date: 2026-05-21
Authors@R: c(person("Soumya", "Ray", email = "soumya.ray@gmail.com", role = c("aut", "ths")),
             person("Nicholas Patrick", "Danks", email = "nicholasdanks@hotmail.com", role = c("aut","cre")),
             person("André", "Calero Valdez", role = "aut", email = "andrecalerovaldez@gmail.com"),
             person("Juan Manuel Velasquez", "Estrada", role = "ctb"),
             person("James", "Uanhoro", role = "ctb", email = "James.uanhoro@gmail.com"),
             person("Johannes", "Nakayama", role = "ctb", email = "johannes.nakayama@rwth-aachen.de"),
             person("Lilian", "Koyan", role = "ctb", email = "lilian.kojan@rwth-aachen.de"),
             person("Laura", "Burbach", role = "ctb", email = "laura.burbach@rwth-aachen.de"),
             person("Arturo Heynar", "Cano Bejar", role = "ctb", email = "arturocano997@gmail.com"),
             person("Susanne", "Adler", role = "ctb", email = "susanne.adler@ovgu.de")
            )
Description: A powerful, easy to use syntax for specifying and estimating complex 
    Structural Equation Models. Models can be estimated using Partial 
    Least Squares Path Modeling or Covariance-Based Structural Equation 
    Modeling or covariance based Confirmatory Factor Analysis (Ray, Danks, and Valdez 2021 <doi:10.2139/ssrn.3900621>).
Imports: parallel, lavaan, glue, DiagrammeR (>= 1.0.6), DiagrammeRsvg
        (>= 0.1), stats
Suggests: knitr, rmarkdown, testthat, webp
License: GPL-3
Depends: R (>= 4.1.0)
LazyData: TRUE
URL: https://github.com/sem-in-r/seminr
BugReports: https://github.com/sem-in-r/seminr/issues
RoxygenNote: 7.3.3
Enhances: rsvg (>= 2.1), semPlot, vdiffr, seminrExtras
VignetteBuilder: knitr
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-05-25 08:01:12 UTC; nicholasdanks
Author: Soumya Ray [aut, ths],
  Nicholas Patrick Danks [aut, cre],
  André Calero Valdez [aut],
  Juan Manuel Velasquez Estrada [ctb],
  James Uanhoro [ctb],
  Johannes Nakayama [ctb],
  Lilian Koyan [ctb],
  Laura Burbach [ctb],
  Arturo Heynar Cano Bejar [ctb],
  Susanne Adler [ctb]
Maintainer: Nicholas Patrick Danks <nicholasdanks@hotmail.com>
Repository: CRAN
Date/Publication: 2026-05-25 08:40:02 UTC
Built: R 4.5.2; ; 2026-05-25 09:44:09 UTC; unix
